from setuptools import setup, find_packages
setup(
name='employeesystem',
version='1.0.0',
author='Grayson Huey',
author_email='graysonhuey02@gmail.com',
description='Manage your workplace employees',
packages=find_packages(),
classifiers=[
'Programming Language :: Python :: 3',
'License :: OSI Approved :: MIT License',
'Operating System :: OS Independent',
],
python_requires='>=3.11',
)